using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace Client
{
	/// <summary>
	/// Window that displays all available candidates 
	/// and allows the user to pick one and vote
	/// </summary>
	public class VoteDisplay : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.ListBox listBox1;
		private System.Windows.Forms.Button vote_button;
		private Client client;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		/// <summary>
		/// Constructor for the screen that shows available candidates
		/// in a requested election
		/// </summary>
		/// <param name="list"></param>
		/// <param name="election"></param>
		/// <param name="client"></param>
		public VoteDisplay(ArrayList list, string election, Client client)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
			
			this.client = client;

			//Adds the candidates to the list
			this.SuspendLayout();
			ArrayList vector = list;
			string[] st = new string[vector.Count];
			for (int i=0; i<vector.Count; i++)
				st[i] = (string)vector[i];
			this.listBox1.Items.AddRange(st);
			this.label1.Text = election;
			this.ResumeLayout(false);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.label1 = new System.Windows.Forms.Label();
			this.listBox1 = new System.Windows.Forms.ListBox();
			this.vote_button = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(64, 8);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(152, 23);
			this.label1.TabIndex = 0;
			// 
			// listBox1
			// 
			this.listBox1.Location = new System.Drawing.Point(48, 48);
			this.listBox1.Name = "listBox1";
			this.listBox1.Size = new System.Drawing.Size(176, 56);
			this.listBox1.TabIndex = 1;
			// 
			// vote_button
			// 
			this.vote_button.Location = new System.Drawing.Point(96, 128);
			this.vote_button.Name = "vote_button";
			this.vote_button.TabIndex = 2;
			this.vote_button.Text = "Vote";
			this.vote_button.Click += new System.EventHandler(this.vote_button_Click);
			// 
			// VoteDisplay
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(264, 173);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.vote_button,
																		  this.listBox1,
																		  this.label1});
			this.Name = "VoteDisplay";
			this.Text = "Vote Display";
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// Method called when the user press "Vote" button.
		/// Calls the appropriate method through the Client object.
		/// Exits the program.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void vote_button_Click(object sender, System.EventArgs e)
		{
			string candidate = (string)this.listBox1.SelectedItem;
			if (candidate == null) 
			{
				MessageBox.Show("To vote, you must choose a candidate from the list", "Error");
				return;
			}
			
			try 
			{
				client.vote((string)this.label1.Text, candidate, this);
				Application.Exit();
				
			}
			catch (DisplayException ex) 
			{
				MessageBox.Show(ex.Message, "Error");
				Application.Exit();
			}
		}
	}
}
